## INTRODUCTION

ima is a command line tool used to search and download images on the internet. It uses either
**Google**, **Duckduckgo**, or **Yahoo** to requests for links and then follow those links to
extract images.
ima has multiple options you may want to use especially when it fails to give reasonable results.
